#
# spec file for package vncmanager-controller
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           vncmanager-controller
Version:        1.0.2
Release:        lp160.1.2
Summary:        Configuration application for VNC session
License:        MIT
Group:          System/X11/Utilities
URL:            https://github.com/openSUSE/vncmanager-controller
Source:         %{name}-%{version}.tar
Patch1:         n_UsrEtc.patch

BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  libQt5Core-devel
BuildRequires:  libQt5Network-devel
BuildRequires:  libQt5Widgets-devel
BuildRequires:  libXvnc-devel
BuildRequires:  libqt5-qtx11extras-devel
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xproto)

Requires:       vncmanager

%description
This is configuration application to configure sharing and security from inside VNC session.

%package gnome
Requires:       gnome-shell
Requires:       vncmanager-controller
Supplements:    (%{name}:gnome-shell)
Summary:        Configuration application for VNC session
Group:          System/GUI/GNOME
BuildArch:      noarch

%description gnome
This is configuration application to configure sharing and security from inside VNC session.

%prep
%setup
%if 0%{?suse_version} >= 1550
%patch -P 1 -p1
%endif

%build
%cmake -DCMAKE_BUILD_TYPE=RelWithDebInfo -DCMAKE_VERBOSE_MAKEFILE=ON
%make_jobs

%install
%cmake_install

%files
%defattr(-,root,root)
%{_bindir}/vncmanager-controller
%if 0%{?suse_version} >= 1550
%dir %{_distconfdir}/xdg
%dir %{_distconfdir}/xdg/autostart
%{_distconfdir}/xdg/autostart/vncmanager-controller.desktop
%else
%dir %{_sysconfdir}/xdg/autostart
%{_sysconfdir}/xdg/autostart/vncmanager-controller.desktop
%endif
%doc LICENSE

%files gnome
%defattr(-,root,root)
%dir %{_datadir}/gnome-shell
%dir %{_datadir}/gnome-shell/extensions
%{_datadir}/gnome-shell/extensions/*

%changelog
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Mon Aug 28 2023 Joan Torres <joan.torres@suse.com>
- Use obs_scm targeting the new github repo at
  https://github.com/openSUSE/vncmanager-controller
- Update to version 1.0.2:
  * Fixes bsc#1214410 with forcing the use of xcb platform plugin
- Drop updated upstream patches:
  * U_Declare-gnome-shell-versions-3.10-to-3.26-as-support.patch
  * u_Declare-also-gnome-shell-versions-3.27-to-41-as-supp.patch
  * 0001-fix-js-code-incompatibility-with-gnome-3.34.patch
- Cleanup specfile
* Tue Mar  8 2022 Stefan Dirsch <sndirsch@suse.com>
- replace broken U_vncmanager-controller-Declare-gnome-shell-versions-3.10-to-3.34-as-supported.patch
  again with latest upstream commit U_Declare-gnome-shell-versions-3.10-to-3.26-as-support.patch
- u_Declare-also-gnome-shell-versions-3.27-to-41-as-supp.patch
  * Declare also gnome shell versions 3.27 to 41 as supported
* Fri Aug  6 2021 Ali Abdallah <ali.abdallah@suse.com>
- 0001-fix-js-code-incompatibility-with-gnome-3.34.patch: Fix JS code
  code incompatibility with newer gnome-shell versions such as gnome-shell
  3.34 (bsc#1188118)
- Explicitly declare newer gnome-shell versions as supported.
  * Added U_vncmanager-controller-Declare-gnome-shell-versions-3.10-to-3.34-as-supported.patch
  * Deleted U_vncmanager-controller-Declare-gnome-shell-versions-3.10-to-3.26-as-supported.patch
* Wed Sep 23 2020 Stefan Dirsch <sndirsch@suse.com>
- n_UsrEtc.patch
  * move autostart file to /usr/etc/xdg/autostart (boo#1173048)
* Fri Nov  8 2019 Stefan Dirsch <sndirsch@suse.com>
- patch U_vncmanager-controller-Declare-gnome-shell-versions-3.10-to-3.26-as-supported.patch
  mentioned in previous changelog enty also covers the fix for
  bsc#1102080 (same issue)
* Tue Jul 17 2018 msrb@suse.com
- U_vncmanager-controller-Declare-gnome-shell-versions-3.10-to-3.26-as-supported.patch
  * Makes the extension load on newer gnome shell versions.
    (bnc#1100768)
* Mon Jun 11 2018 msrb@suse.com
- Update to version 1.0.1
  * Fixes build with Qt 5.11
  * Remove patch which is now included:
    U_vncmanager-fix-installation-directory-and-metadata-of-gnome-shell-extension.patch
* Thu Mar  1 2018 sndirsch@suse.com
- fixed Buildrequires to use pkconfig files instead of devel
  package names
* Wed May 18 2016 msrb@suse.com
- Improve dependencies. (bnc#980573)
* Thu May 12 2016 msrb@suse.com
- U_vncmanager-fix-installation-directory-and-metadata-of-gnome-shell-extension.patch
  (bnc#979647)
- Add LICENSE file to docs.
* Fri Apr 29 2016 msrb@suse.com
- Change group to System/X11/Utilities.
* Tue Jan 19 2016 msrb@suse.com
- Switch to Qt5.
* Mon Nov  9 2015 msrb@suse.com
- Create package.
